/*!
 * Perth
 * PSD Created by Peter Finlan http://dribbble.com/peterfinlan
 *
 * Coding by Theme Armada
 * Visit us for more Bootstrap themes at: http://www.themearmada.com
 * Handcrafted with love in Atlanta!
 */

/* ==========================================================================
   Global styles
   ========================================================================== */
h1 {
  font-family: 'Dr Sugiyama', cursive;
}

h2, h3, p, .navbar-nav {
  font-family: 'Lato', sans-serif;
} 



h1 {
  font-size: 62px;
  color: #ffffff;
}


h2 {
  font-size: 42px;
  font-weight: 300;
  color: #545454;
}

h3 {
  font-size: 30px;
  font-weight: 300;
  color: #ffffff;
}

p {
  color: #7e7e7e;
  font-size: 16px;
}


/*-------------------Margins----------------*/
.margin-0 {
    margin-bottom: 0 !important;
}
.margin-10 {
    margin-bottom: 10px !important;
}
.margin-15 {
    margin-bottom: 15px !important;
}
.margin-20 {
    margin-bottom: 20px !important;
}
.margin-30 {
    margin-bottom: 30px !important;
}
.margin-40 {
    margin-bottom: 40px !important;
}
.margin-50 {
    margin-bottom: 50px !important;
}
.margin-60 {
    margin-bottom: 60px !important;
}
.margin-70 {
    margin-bottom: 70px !important;
}
.margin-80 {
    margin-bottom: 80px !important;
}
.margin-90 {
    margin-bottom: 90px !important;
}
.margin-100 {
    margin-bottom: 100px !important;
}



/*-------------------Buttons----------------*/
.btn {
    -moz-user-select: none;
    background-image: none;
    border: 1px solid rgba(0, 0, 0, 0);
    border-radius: 2px;
    cursor: pointer;
    display: inline-block;
    font-size: 14px;
    font-weight: 400;
    line-height: 1.42857;
    margin-bottom: 0;
    padding: 6px 12px;
    text-align: center;
    vertical-align: middle;
    white-space: nowrap;
}

.btn-lg {
    border-radius: 2px;
    font-size: 18px;
    line-height: 1.33;
    padding: 14px 22px;
}

.btn-primary {
    background-color: transparent;
    border-color: #FFFFFF;
    color: #FFFFFF;
}

.btn-primary:hover, .btn-primary:focus, .btn-primary:active, .btn-primary.active, .open .dropdown-toggle.btn-primary {
    background-color: #ffffff;
    border-color: #FFFFFF;
    color: #545454;
    
    -webkit-transition: all 0.35s ease-in-out;
    -moz-transition: all 0.35s ease-in-out;
    -o-transition: all 0.35s ease-in-out;
    transition: all 0.35s ease-in-out;
}

.btn-secondary {
    background-color: transparent;
    border-color: #4eacdd;
    color: #4eacdd;
}

.btn-secondary:hover, .btn-secondary:focus, .btn-secondary:active, .btn-secondary.active, .open .dropdown-toggle.btn-secondary {
    background-color: #4eacdd;
    border-color: #4eacdd;
    color: #ffffff;
    
    -webkit-transition: all 0.35s ease-in-out;
    -moz-transition: all 0.35s ease-in-out;
    -o-transition: all 0.35s ease-in-out;
    transition: all 0.35s ease-in-out;
}


/*-------------------Colors----------------*/
.dark-gray {
  color: #545454;
}

.light-gray {
  color: #f4f4f4;
}

.white {
  color: #ffffff;
}

.green {
  color: #13c4af;
}

.blue {
  color: #4eacdd;
}



/* ==========================================================================
   Navigation styles
   ========================================================================== */
.navbar-inverse {
    background-color: #4eabde;
    border-color: rgba(0, 0, 0, 0);
}

.navbar-brand {
    padding: 0px;
}

.navbar {
  margin-bottom: 0px;
}

.navbar-inverse .navbar-nav > li > a {
    color: #ffffff;
    font-weight: 400;
    text-transform: uppercase;
}

.navbar-inverse .navbar-toggle {
    border-color: rgba(0, 0, 0, 0);
}

.navbar-inverse .navbar-toggle:hover, .navbar-inverse .navbar-toggle:focus {
    background-color: rgba(0, 0, 0, 0);
}

.navbar-inverse .navbar-collapse, .navbar-inverse .navbar-form {
    border-color: rgba(0, 0, 0, 0);
    border: 0px;
    box-shadow: 0 0px 0 rgba(0, 0, 0, 0.0) inset;
}







/* ==========================================================================
   Main styles
   ========================================================================== */
#header {
  background: #4eacdd;
  height: 650px;
  overflow: hidden;
}


.header-text {
  padding-top: 175px;
} 
   
.header-img {
  margin-top: -100px;
}   
   
#main1 {
  background: #f4f4f4;
  padding-top: 140px;
  min-height: 650px;
  overflow: hidden;
  height: auto;
}

.main1-img {
  position: absolute;
  right: 0;
}


blockquote {
    border-left: 8px solid #4eacdd;
    font-size: 16.5px;
    color: #7e7e7e;
    font-style: italic;
    margin: 0 0 20px;
    padding: 0px 20px;
}

#main2 {
  background: #ffffff;
  padding-top: 140px;
  height: 650px;
  overflow: hidden;
}

.main2-img {
    left: 0;
    margin-left: -300px;
    margin-top: 160px;
    position: absolute;
}

#message {
  padding: 100px 0px;
  background: #13c4af;
}

#bottom {
  padding: 220px 0px;
  background: #f4f4f4;
  overflow-y: hidden;
}

.social li a {
  width: 60px;
  height: 60px;
  border-radius: 30px;
  border: 2px solid #545454;
  background: transparent;
  color: #545454;
  padding: 14px 16px;
  display: block;
}

.social li a:hover {
  border: 2px solid #aeaeae;
  background: transparent;
  color: #aeaeae;
  
  -webkit-transition: all 0.35s ease-in-out;
    -moz-transition: all 0.35s ease-in-out;
    -o-transition: all 0.35s ease-in-out;
    transition: all 0.35s ease-in-out;
}

.social li {
  margin-left: 15px;
  margin-right: 15px;
}

.form-control {
    background-color: #FFFFFF;
    background-image: none;
    border: 0 solid #CCCCCC;
    border-radius: 2px;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.075) inset;
    color: #555555;
    display: block;
    font-size: 14px;
    height: 55px;
    line-height: 1.42857;
    padding: 6px 12px;
    transition: border-color 0.15s ease-in-out 0s, box-shadow 0.15s ease-in-out 0s;
    width: 100%;
}

footer {
  background: #ffffff;
  padding: 40px 0px;
}



/* ==========================================================================
   Mobile styles
   ========================================================================== */   
/* Landscape phones and down */
@media (max-width: 480px) { 

.header-img {
  position: absolute;
  margin-left: -120px;
  left:0;
}

#main1 {
   padding-bottom: 170px;
}

.navbar-nav {
  text-align: right;
}

.main2-img {
    margin-left: 150px;
    margin-top: 360px; 
    width: 100%;
    max-width: 600px;  
}
	
}

/* Landscape phone to portrait tablet */
@media (min-width: 481px) and (max-width: 767px) { 

.header-img {
  position: absolute;
  margin-left: -30px;
  left:0;
}

#main1 {
   padding-bottom: 170px;
}

.navbar-nav {
  text-align: right;
}

.main2-img {
    margin-left: 150px;
    margin-top: 260px; 
    width: 100%;
    max-width: 600px;  
}

}


/* Portrait tablet to landscape and desktop */
@media (min-width: 768px) and (max-width: 991px) {

.main2-img {
    margin-left: -550px;
   
}


}



/* Desktops and laptops */
@media (min-width: 992px) and (max-width: 1199px) {

.main2-img {
    margin-left: -400px;
   
}

}
     


/* Large screens */
@media (min-width: 1200px) and (max-width: 3000px) {

}   

